@@ -90,7 +90,7 @@ soup_message_headers_new (SoupMessageHeadersType type)
 static SoupMessageHeaders *
 soup_message_headers_copy (SoupMessageHeaders *hdrs)
 {
-	hdrs->ref_count++;
+	g_atomic_int_inc (&hdrs->ref_count);
 	return hdrs;
 }
 
@@ -103,12 +103,13 @@ soup_message_headers_copy (SoupMessageHeaders *hdrs)
 void
 soup_message_headers_free (SoupMessageHeaders *hdrs)
 {
-	if (--hdrs->ref_count == 0) {
-		soup_message_headers_clear (hdrs);
-		g_array_free (hdrs->array, TRUE);
-		g_clear_pointer (&hdrs->concat, g_hash_table_destroy);
-		g_slice_free (SoupMessageHeaders, hdrs);
-	}
+	if (!g_atomic_int_dec_and_test (&hdrs->ref_count))
+		return;
+
+	soup_message_headers_clear (hdrs);
+	g_array_free (hdrs->array, TRUE);
+	g_clear_pointer (&hdrs->concat, g_hash_table_destroy);
+	g_slice_free (SoupMessageHeaders, hdrs);
 }
 
 G_DEFINE_BOXED_TYPE (SoupMessageHeaders, soup_message_headers, soup_message_headers_copy, soup_message_headers_free)
@@ -1323,18 +1324,20 @@ static void
 content_type_setter (SoupMessageHeaders *hdrs, const char *value)
 {
 	g_free (hdrs->content_type);
+	hdrs->content_type = NULL;
+
 	if (value) {
-		char *content_type, *p;
+		char *content_type = NULL, *p;
 
 		parse_content_foo (hdrs, "Content-Type", &content_type, NULL);
+		g_return_if_fail (content_type != NULL);
+
 		p = strpbrk (content_type, " /");
-		if (!p || *p != '/' || strpbrk (p + 1, " /")) {
+		if (!p || *p != '/' || strpbrk (p + 1, " /"))
 			g_free (content_type);
-			hdrs->content_type = NULL;
-		} else
+		else
 			hdrs->content_type = content_type;
-	} else
-		hdrs->content_type = NULL;
+	}
 }
 
 /**
